package xhttp3.internal.http;

import java.util.List;
import xhttp3.Connection;
import xhttp3.HttpUrl;
import xhttp3.Interceptor;
import xhttp3.Request;
import xhttp3.Response;
import xhttp3.internal.connection.StreamAllocation;

public final class RealInterceptorChain implements Interceptor.Chain {
   private final List<Interceptor> interceptors;
   private final StreamAllocation streamAllocation;
   private final HttpStream httpStream;
   private final Connection connection;
   private final int index;
   private final Request request;
   private int calls;

   public RealInterceptorChain(List<Interceptor> interceptors, StreamAllocation streamAllocation, HttpStream httpStream, Connection connection, int index, Request request) {
      this.interceptors = interceptors;
      this.connection = connection;
      this.streamAllocation = streamAllocation;
      this.httpStream = httpStream;
      this.index = index;
      this.request = request;
   }

   private boolean sameConnection(HttpUrl url) {
      return url.host().equals(this.connection.route().address().url().host()) && url.port() == this.connection.route().address().url().port();
   }

   public Connection connection() {
      return this.connection;
   }

   public StreamAllocation streamAllocation() {
      return this.streamAllocation;
   }

   public HttpStream httpStream() {
      return this.httpStream;
   }

   public Request request() {
      return this.request;
   }

   public Response proceed(Request request) {
      RealInterceptorChain var10000 = this;
      Request var10001 = request;
      RealInterceptorChain var10002 = this;
      RealInterceptorChain var10003 = this;
      StreamAllocation var3 = this.streamAllocation;
      HttpStream request1 = var10003.httpStream;
      Connection var2 = var10002.connection;
      return var10000.proceed(var10001, var3, request1, var2);
   }

   public Response proceed(Request request, StreamAllocation streamAllocation, HttpStream httpStream, Connection connection) {
      if (this.index < this.interceptors.size()) {
         ++this.calls;
         if (this.httpStream != null && !this.sameConnection(request.url())) {
            throw new IllegalStateException("network interceptor " + this.interceptors.get(this.index - 1) + " must retain the same host and port");
         } else if (this.httpStream != null && this.calls > 1) {
            throw new IllegalStateException("network interceptor " + this.interceptors.get(this.index - 1) + " must call proceed() exactly once");
         } else {
            RealInterceptorChain var5;
            RealInterceptorChain var10002 = var5 = new RealInterceptorChain;
            int streamAllocation1 = this.index + 1;
            var10002.<init>(this.interceptors, streamAllocation, httpStream, connection, streamAllocation1, request);
            Interceptor request1;
            Response streamAllocation2 = (request1 = (Interceptor)this.interceptors.get(this.index)).intercept(var5);
            if (httpStream != null && this.index + 1 < this.interceptors.size() && var5.calls != 1) {
               throw new IllegalStateException("network interceptor " + request1 + " must call proceed() exactly once");
            } else if (streamAllocation2 != null) {
               return streamAllocation2;
            } else {
               throw new NullPointerException("interceptor " + request1 + " returned null");
            }
         }
      } else {
         throw new AssertionError();
      }
   }
}
